"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListenerLayer = void 0;
const events_1 = require("events");
const enum_1 = require("../../model/enum/");
const whatsapp_1 = require("./whatsapp");
const help_1 = require("../../help");
class ListenerLayer extends whatsapp_1.Whatsapp {
    constructor(page, browser, options, ev) {
        super(page, browser, options, ev);
        this.page = page;
        this.browser = browser;
        this.options = options;
        this.ev = ev;
        this.urlCode = '';
        this.listenerEmitter = new events_1.EventEmitter();
    }
    async qrCodeScan() {
        var _a;
        this.startAutoClose();
        await this.page
            .waitForFunction(`document.querySelector('canvas')`)
            .catch(() => undefined);
        while (true) {
            const result = await this.qrCode().catch();
            if (!(result === null || result === void 0 ? void 0 : result.urlCode)) {
                break;
            }
            if (this.urlCode !== result.urlCode) {
                this.urlCode = result.urlCode;
                this.ev.statusFind = {
                    erro: false,
                    qrcode: result.urlCode,
                    base64Image: result.base64Image,
                    onType: enum_1.onMode.qrcode,
                    session: this.options.session,
                };
                const qr = await this.asciiQr(this.urlCode).catch(() => undefined);
                if (this.options.printQRInTerminal) {
                    console.log(qr);
                }
            }
            await ((_a = (0, help_1.sleep)(100)) === null || _a === void 0 ? void 0 : _a.catch(() => undefined));
        }
    }
    async initListener() {
        const functions = [...Object.values(enum_1.onMode)];
        for (const func of functions) {
            const has = await this.page
                .evaluate((func) => typeof window[func] === 'function', func)
                .catch(() => false);
            if (!has) {
                await this.page
                    .exposeFunction(func, (...args) => this.listenerEmitter.emit(func, ...args))
                    .catch(() => { });
            }
        }
        this.listener(enum_1.onMode.interfaceChange);
        this.listener(enum_1.onMode.newMessage);
        this.listener(enum_1.onMode.newOnAck);
        this.interfaceChange();
        this.newMessage();
        this.newOnAck();
    }
    listener(type) {
        this.listenerEmitter.on(type, (event) => {
            this.ev.statusFind = {
                onType: type,
                session: this.options.session,
                result: event,
            };
        });
        return {
            dispose: () => {
                this.listenerEmitter.off(type, (event) => {
                    this.ev.statusFind = {
                        onType: type,
                        session: this.options.session,
                        result: event,
                    };
                });
            },
        };
    }
}
exports.ListenerLayer = ListenerLayer;
//# sourceMappingURL=listener.layes.js.map